%global         pypi_name      getdist

Name:           python-getdist
Version:        1.5.4
Release:        %mkrel 1
Summary:        A samples analyzer for Markov Chain Monte Carlo (MCMC)
License:        MIT
Group:          Development/Python
URL:            https://pypi.python.org/pypi/GetDist
Source0:        %{pypi_source}
Patch0:         getdist-1.5.2-mplvermin.patch

BuildArch:      noarch

%description
Getdist is a python package for analyzing Monte Carlo samples,
including correlated samples from Markov Chain Monte Carlo (MCMC). It
provides a point and click GUI allowing to select chain files, view
plots, extract marginalized constraints, generate LaTeX tables and
more. GetDist is also a plotting library which can be imported in any
python code to make custom publication-ready multi-dimensional and
triangle plots. The underlying code incorporates an automated optimal
bandwidth choice to extract smooth 1D and 2D densities based on the
Botev-Sheather-Jones method. Convergence diagnostics are also reported
by computing correlation length and diagonalized Gelman-Rubin
statistics.

%package -n python3-getdist
Summary:        Python3 implementation of GetDist
Group:          Development/Python
%{?python_provide:%python_provide python3-getdist}
BuildRequires:  python3
BuildRequires:  python3dist(setuptools)
Requires:       python3-numpy
Requires:       python3-scipy
Requires:       python3-pyside6
Requires:       python3-matplotlib-qt5
Requires:       latex
Provides:       getdist = %{version}-%{release}

%description -n python3-getdist
Getdist is a python package for analyzing Monte Carlo samples,
including correlated samples from Markov Chain Monte Carlo (MCMC). It
provides a point and click GUI allowing to select chain files, view
plots, extract marginalized constraints, generate LaTeX tables and
more. GetDist is also a plotting library which can be imported in any
python code to make custom publication-ready multi-dimensional and
triangle plots. The underlying code incorporates an automated optimal
bandwidth choice to extract smooth 1D and 2D densities based on the
Botev-Sheather-Jones method. Convergence diagnostics are also reported
by computing correlation length and diagonalized Gelman-Rubin
statistics.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files getdist

%__rm -r -f %{buildroot}%{python3_sitelib}/docs

%files -n python3-getdist -f %{pyproject_files}
%doc README.rst
%{_bindir}/getdist*


%changelog
* Mon Dec 09 2024 eatdirt <eatdirt> 1.5.4-1.mga10
+ Revision: 2123185
- Update to version 1.5.4

* Tue Sep 10 2024 eatdirt <eatdirt> 1.5.2-1.mga10
+ Revision: 2094905
- Upgrade to version 1.5.2

* Mon Apr 15 2024 eatdirt <eatdirt> 1.4.8-1.mga10
+ Revision: 2057789
- Update to version 1.4.8

* Thu Mar 07 2024 papoteur <papoteur> 1.4.7-1.mga10
+ Revision: 2048304
- new version 1.4.7

* Sat Jan 27 2024 daviddavid <daviddavid> 1.4.5-2.mga10
+ Revision: 2035312
- switch to PySide6

* Thu Oct 19 2023 eatdirt <eatdirt> 1.4.5-1.mga10
+ Revision: 1999255
- Update to version 1.4.5

* Tue May 30 2023 eatdirt <eatdirt> 1.4.3-1.mga9
+ Revision: 1959767
- Update to release 1.4.3

* Fri Mar 17 2023 eatdirt <eatdirt> 1.4.2-1.mga9
+ Revision: 1949601
- Update to version 1.4.2

* Sat Dec 03 2022 eatdirt <eatdirt> 1.4-1.mga9
+ Revision: 1916132
- Upgrade to version 1.4

* Sun Apr 10 2022 eatdirt <eatdirt> 1.3.4-3.mga9
+ Revision: 1848667
- Rebuild for new matplotlib

* Wed Mar 23 2022 umeabot <umeabot> 1.3.4-2.mga9
+ Revision: 1823758
- Mageia 9 Mass Rebuild

* Fri Feb 25 2022 mrambo3501 <mrambo3501> 1.3.4-1.mga9
+ Revision: 1784483
- version 1.3.4
- rebuild for python-3.10

* Fri Aug 27 2021 eatdirt <eatdirt> 1.3.2-1.mga9
+ Revision: 1742909
- Update to version 1.3.2

* Sat Jun 26 2021 wally <wally> 1.3.0-2.mga9
+ Revision: 1732970
- Rebuild for python 3.9

* Fri Jun 11 2021 eatdirt <eatdirt> 1.3.0-1.mga9
+ Revision: 1730408
- Upgrade to version 1.3.0

* Sat Jul 11 2020 eatdirt <eatdirt> 1.1.2-1.mga8
+ Revision: 1605185
- Upgrade to version 1.1.2

* Wed Mar 18 2020 eatdirt <eatdirt> 1.1.0-1.mga8
+ Revision: 1557665
- Upgrade to version 1.1.0

* Sun Feb 16 2020 umeabot <umeabot> 0.3.3-2.mga8
+ Revision: 1531759
- Mageia 8 Mass Rebuild

* Sat Sep 14 2019 wally <wally> 0.3.3-1.mga8
+ Revision: 1440896
- new version 0.3.3
- switch to pyside2
- drop python2 support

* Tue Mar 05 2019 eatdirt <eatdirt> 0.3.2-1.mga7
+ Revision: 1371682
- Upgrade to version 0.3.2

* Sat Jan 12 2019 tmb <tmb> 0.2.8.4.2-3.mga7
+ Revision: 1355233
- rebuild for python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.2.8.4.2-2.mga7
+ Revision: 1288919
- Mageia 7 Mass Rebuild

* Tue Jan 30 2018 eatdirt <eatdirt> 0.2.8.4.2-1.mga7
+ Revision: 1198118
- Upgrade to version 0.2.8.4.2

* Sat Aug 05 2017 pterjan <pterjan> 0.2.7-2.mga7
+ Revision: 1135431
- Rebuild for python 3.6

* Mon Apr 03 2017 eatdirt <eatdirt> 0.2.7-1.mga6
+ Revision: 1095794
- Upgrade to version 0.2.7

* Thu Dec 01 2016 eatdirt <eatdirt> 0.2.6-1.mga6
+ Revision: 1071451
- Upgrade to latest stable

* Thu Oct 06 2016 eatdirt <eatdirt> 0.2.6-0.gita14cf5f.4.mga6
+ Revision: 1059271
- Update prerelease to latest git commit

* Fri Mar 18 2016 eatdirt <eatdirt> 0.2.6-0.git9133bc2.3.mga6
+ Revision: 992830
- Upgrade to latest git

* Fri Feb 19 2016 umeabot <umeabot> 0.2.6-0.git98b029f88d.2.mga6
+ Revision: 970572
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 eatdirt <eatdirt> 0.2.6-0.git98b029f88d.1.mga6
+ Revision: 887208
- Upgrade to latest git HEAD, rebuild for new python

* Fri Jul 31 2015 eatdirt <eatdirt> 0.2.5-2.mga6
+ Revision: 859843
- Fix wrong ref to python3 in GetDist.py

* Thu Jul 30 2015 eatdirt <eatdirt> 0.2.5-1.mga6
+ Revision: 859136
- imported package python-getdist

